@@ -22,6 +22,11 @@
 #' @name tensorflow
 NULL
 
+# globals
+.globals <- new.env(parent = emptyenv())
+.globals$tensorboards <- new.env(parent = emptyenv())
+
+
 .onLoad <- function(libname, pkgname) {
 
   # if TENSORFLOW_PYTHON is defined then forward it to RETICULATE_PYTHON
@@ -59,6 +64,7 @@ NULL
 }
 
 
+
 #' TensorFlow configuration information
 #'
 #' @return List with information on the current configuration of TensorFlow.
@@ -102,6 +108,18 @@ tf_config <- function() {
   }
 }
 
+
+#' @rdname tf_config
+#' @keywords internal
+#' @export
+tf_version <- function() {
+  config <- tf_config()
+  if (config$available)
+    config$version
+  else
+    NULL
+}
+
 #' @export
 print.tensorflow_config <- function(x, ...) {
   if (x$available) {
