@@ -26,4 +26,8 @@ is_ubuntu <- function() {
   }
 }
 
+ensure_loaded <- function() {
+  invisible(tf$`__version__`)
+}
+
 
